<?php
function getProjConfig() {
	$projConfig = array(
		"HFCS00_Base" => "hfcs2020_config",
		"HFCS01_Screener" => "hfcs2020_config",
		"HFCS02_Merkmale" => "hfcs2020_config",
		"HFCS03_Konsum" => "hfcs2020_config",
		"HFCS04_Immobilien" => "hfcs2020_config",
		"HFCS05_Kredite" => "hfcs2020_config",
		"HFCS06_Beteiligungen" => "hfcs2020_config",
		"HFCS07_Erbschaften" => "hfcs2020_config",
		"HFCS08_Erwerb" => "hfcs2020_config",
		//"HFCS09_Einkommen" => "hfcs2020_config", //in Erwerb inkludiert
		//"HFCS06_Pension" => "hfcs2020_config", //in Erwerb inkludiert
		"HFCS11_Einschaetzung" => "hfcs2020_config",
		"HFCS12_Abschluss" => "hfcs2020_config",
		//"HFCS01_Screener" => "hfcs2020_config",
		"HFCS00_Paradaten" => "hfcs2020_config",
	);
	//echo $_SESSION['projname'];
	$config = $projConfig[$_SESSION['projname']];
	//echo $config;
	include_once 'ProjConfigs/'.$config.'.php';
	return true;
}
function get_quest_text () {
	return true;
}

function isProxy() {
	if (reset(getVarFromHFCS("HFCS01_Screener","AHL0130"))==1) {
		return false;
	} else {
		return true;
	}
}
function anzPers() {
	$anzPers = 0;
	if (getVarFromHFCS("HFCS01_Screener","dtxtvars_3")) return reset(getVarFromHFCS("HFCS01_Screener","dtxtvars_3"));
	else return false;
}
function anzPersErfassung() {
	$anzPers = 0;
	$anzZusatz = 0;
	if (getVarFromHFCS("HFCS01_Screener","AHL0210_1")) $anzPers=reset(getVarFromHFCS("HFCS01_Screener","AHL0210_1"));
	// echo "anzPers".$anzPers."<br>";
	if (getVarFromHFCS("HFCS01_Screener","AHL0240_1")) $anzZusatz=reset(getVarFromHFCS("HFCS01_Screener","AHL0240_1"));
	// echo "anzZusatz".$anzZusatz."<br>";
	return $anzPers+$anzZusatz;
}
function makePersList($typ="eligible") {
	$anzPers = anzPersErfassung();
	//echo $anzPers."<br>";
	for ($pers=1;$pers<=15;$pers++) {
		$name = reset(getVarFromHFCS("HFCS01_Screener","RA000x".$pers."_1"));
		$filter = true;
		if ($typ=="eligible") $filter = checkEligible($pers);
		$sex = getSex($pers);
		$age = getAge($pers);
		$bez = getBez($pers);
		if ($pers<=$anzPers && $filter) {
			// echo "Personen:<br><br><br><br><br>".$pers;
			saveVar("dumPers_".$pers."='".$name." (".$sex.", ".$age." - ".$bez.")'");
		} else {
			saveVar("dumPers_".$pers."=NULL");
		}
	}
	if (isProxy()) saveVar("dumPers_16='".reset(getVarFromHFCS("HFCS01_Screener","AHL0140_opn"))." (Kompetenzträger)'");
		else saveVar("dumPers_16=NULL");
}
function checkStatus($fbTeil,$loginSID,$finalQuest = "ENDIV") {
	// echo "Fragebogenteil ".$fbTeil."<br>";
	$loginSID = explode("-",$loginSID);
	// echo "loginSID ".$loginSID[1]."<br>";
	// echo "finalQuest ".$finalQuest."<br>";
	$records = getVarFromTable($fbTeil."_structure", $finalQuest, "WHERE id_loginSID=".$loginSID[1]);
	// echo "ANZAHL: ".count($records)."<br>";
	$complete = false;
	if(count($records)>0)	{
		// dumpvar($records[0]);
		foreach($records as $record) {
			if ($record[$finalQuest]==1) $complete=true;
		}
	}
	return $complete;
}
function getMaxAgeHH() {
	$maxage = 0;
	for ($iloop=1;$iloop<=15;$iloop++) {
		$age = getAgeInt($iloop);
		if($age>=16 && $age<=110 && $age>$maxage ) $maxage = $age;
	}
	if ($maxage>0) return $maxage;
	else return false;
}
function checkAgeHHu18() {
	$u18 = 0;
	for ($iloop=1;$iloop<=15;$iloop++) {
		$age = getAgeInt($iloop);
		if($age>=0 && $age<=17) $u18 = 1;
	}
	if ($u18==1) return true;
	else return false;
}
function getAgeInt($persnr) {
	return (reset(getVarFromHFCS("HFCS01_Screener","RA030x".$persnr.""))-1);
}
function getAge($persnr) {
	$age_array = array(
		1 => "<1 Jahr",
		2 => "1 Jahr",
		3 => "2 Jahre",
		4 => "3 Jahre",
		5 => "4 Jahre",
		6 => "5 Jahre",
		7 => "6 Jahre",
		8 => "7 Jahre",
		9 => "8 Jahre",
		10 => "9 Jahre",
		11 => "10 Jahre",
		12 => "11 Jahre",
		13 => "12 Jahre",
		14 => "13 Jahre",
		15 => "14 Jahre",
		16 => "15 Jahre",
		17 => "16 Jahre",
		18 => "17 Jahre",
		19 => "18 Jahre",
		20 => "19 Jahre",
		21 => "20 Jahre",
		22 => "21 Jahre",
		23 => "22 Jahre",
		24 => "23 Jahre",
		25 => "24 Jahre",
		26 => "25 Jahre",
		27 => "26 Jahre",
		28 => "27 Jahre",
		29 => "28 Jahre",
		30 => "29 Jahre",
		31 => "30 Jahre",
		32 => "31 Jahre",
		33 => "32 Jahre",
		34 => "33 Jahre",
		35 => "34 Jahre",
		36 => "35 Jahre",
		37 => "36 Jahre",
		38 => "37 Jahre",
		39 => "38 Jahre",
		40 => "39 Jahre",
		41 => "40 Jahre",
		42 => "41 Jahre",
		43 => "42 Jahre",
		44 => "43 Jahre",
		45 => "44 Jahre",
		46 => "45 Jahre",
		47 => "46 Jahre",
		48 => "47 Jahre",
		49 => "48 Jahre",
		50 => "49 Jahre",
		51 => "50 Jahre",
		52 => "51 Jahre",
		53 => "52 Jahre",
		54 => "53 Jahre",
		55 => "54 Jahre",
		56 => "55 Jahre",
		57 => "56 Jahre",
		58 => "57 Jahre",
		59 => "58 Jahre",
		60 => "59 Jahre",
		61 => "60 Jahre",
		62 => "61 Jahre",
		63 => "62 Jahre",
		64 => "63 Jahre",
		65 => "64 Jahre",
		66 => "65 Jahre",
		67 => "66 Jahre",
		68 => "67 Jahre",
		69 => "68 Jahre",
		70 => "69 Jahre",
		71 => "70 Jahre",
		72 => "71 Jahre",
		73 => "72 Jahre",
		74 => "73 Jahre",
		75 => "74 Jahre",
		76 => "75 Jahre",
		77 => "76 Jahre",
		78 => "77 Jahre",
		79 => "78 Jahre",
		80 => "79 Jahre",
		81 => "80 Jahre",
		82 => "81 Jahre",
		83 => "82 Jahre",
		84 => "83 Jahre",
		85 => "84 Jahre",
		86 => "85 Jahre",
		87 => "86 Jahre",
		88 => "87 Jahre",
		89 => "88 Jahre",
		90 => "89 Jahre",
		91 => "90 Jahre",
		92 => "91 Jahre",
		93 => "92 Jahre",
		94 => "93 Jahre",
		95 => "94 Jahre",
		96 => "95 Jahre",
		97 => "96 Jahre",
		98 => "97 Jahre",
		99 => "98 Jahre",
		100 => "99 Jahre",
		101 => "100 Jahre",
		102 => "101 Jahre",
		103 => "102 Jahre",
		104 => "103 Jahre",
		105 => "104 Jahre",
		106 => "105 Jahre",
		107 => "106 Jahre",
		108 => "107 Jahre",
		109 => "108 Jahre",
		110 => "109 Jahre",
		111 => "110 Jahre",
		112 => "Weiß nicht",
		113 => "keine Angabe",
	);
	//echo "alterscode ".reset(getVar("RA030x".$persnr.""))."<br>";
	return $age_array[reset(getVarFromHFCS("HFCS01_Screener","RA030x".$persnr.""))];
}
function getSex($persnr) {
	$age_array = array(
		1 => "männlich",
		2 => "weiblich",
	);
	//echo "alterscode ".reset(getVar("RA030x".$persnr.""))."<br>";
	return $age_array[reset(getVarFromHFCS("HFCS01_Screener","RA020x".$persnr.""))];
}
function getBez($persnr) {
	$age_array = array(
		1  => "Referenzperson",
		2  => "Partner oder Ehepartner der Referenzperson",
		3  => "Sohn  /  Tochter der Referenzperson",
		4  => "Eltern(teil) der Referenzperson",
		5  => "Schwiegereltern(-teil) der Referenzperson",
		6  => "Großeltern der Referenzperson",
		7  => "Enkelkind der Referenzperson",
		8  => "Bruder / Schwester der Referenzperson",
		9  => "Anderweitig verwandt mit der Referenzperson",
		10 => "Anderes Haushaltsmitglied - nicht verwandt mit der Referenzperson",
			);
	//echo "alterscode ".reset(getVar("RA030x".$persnr.""))."<br>";
	return $age_array[reset(getVarFromHFCS("HFCS01_Screener","RA010x".$persnr.""))];
}
function euroloop($interval = "A",$min = 0,$max = 999999999,$sonder = NULL,$preWaehrung = 1) {

	$intervalA = array(
		"A" => "EUR 1 – unter 101",
		"B" => "EUR 101 – unter 201",
		"C" => "EUR 201 -  unter 301",
		"D" => "EUR 301 – unter 401",
		"E" => "EUR 401 – unter 501",
		"F" => "EUR 501 – unter 751",
		"G" => "EUR 751 – unter 1.001",
		"H" => "EUR 1.001 – unter 1.501",
		"I" => "EUR 1.501 – unter 2.001",
		"J" => "EUR 2.001 – unter 3.001",
		"K" => "EUR 3.001 – unter 5.001",
		"L" => "EUR 5.001 – unter 7.501",
		"M" => "EUR 7.501 – unter 10.001",
		"N" => "EUR 10.001 – unter 25.001",
		"O" => "EUR 25.001 – unter 50.001",
		"P" => "Mehr als EUR 50.000",
	);
	$intervalB = array(
		"A" => "EUR 1 – unter 10.001",
		"B" => "EUR 10.001 – unter 50.001",
		"C" => "EUR 50.001 – unter 75.001",
		"D" => "EUR 75.001 – unter 100.001",
		"E" => "EUR 100.001 – unter 150.001",
		"F" => "EUR 150.001 – unter 200.001",
		"G" => "EUR 200.001 – unter 300.001",
		"H" => "EUR 300.001 – unter 400.001",
		"I" => "EUR 400.001 – unter 500.001",
		"J" => "EUR 500.001 – unter 750.001",
		"K" => "EUR 750.001 - 1 Million",
		"L" => "EUR mehr als 1 Million - 3 Millionen",
		"M" => "EUR mehr als 3 Millionen - 5 Millionen",
		"N" => "EUR mehr als 5 Millionen - 10 Millionen",
		"O" => "Mehr als EUR 10 Millionen",
	);
	$intervalC = array(
		"A" => "EUR 1 – unter 1001",
		"B" => "EUR 1.001 – unter 2.501",
		"C" => "EUR 2.501 – unter 5.001",
		"D" => "EUR 5.001 – unter 7.501",
		"E" => "EUR 7.501 – unter 10.001",
		"F" => "EUR 10.001 – unter 15.001",
		"G" => "EUR 15.001 – unter 20.001",
		"H" => "EUR 20.001 – unter 25.001",
		"I" => "EUR 25.001 – unter 30.001",
		"J" => "EUR 30.001 – unter 35.001",
		"K" => "EUR 35.001 – unter 40.001",
		"L" => "EUR 40.001 – unter 50.001",
		"M" => "EUR 50.001 – unter 75.001",
		"N" => "EUR 75.001 – unter 100.001",
		"O" => "EUR 100.001 – unter 200.001",
		"P" => "EUR 200.001 – unter 300.001",
		"Q" => "EUR 300.001 – unter 500.001",
		"R" => "EUR 500.001 - 1 Million",
		"S" => "Mehr als EUR 1 Millionen",
	);
	$waehrungen = array(
		"1" => "Euro (EUR)",
		"2" => "Schilling (ATS)",
		"3" => "Deutsche Mark (DEM)",
		"4" => "Englisches Pfund (GBP)",
		"5" => "Französischer Franc (FRF)",
		"6" => "Kuna, Kroatien (HRK)",
		"7" => "Italienische Lira (ITL)",
		"8" => "Luxemburgische Krone (LUF)",
		"9" => "Schweizer Franken (CHF)",
		"10" => "Serbischer Dinar (RSD)",
		"11" => "Slowakische Krone (SKK)",
		"12" => "Slowenischer Tolar (SIT)",
		"13" => "Ungarischer Forint (HUF)",
		"14" => "US-Dollar (USD)",
		"15" => "Yen, Japan (JPY)",
		"16" => "Andere (bitte angeben)",
	);
	if($interval == "A") $kat = $intervalA;
	if($interval == "B") $kat = $intervalB;
	if($interval == "C") $kat = $intervalC;

	echo '<input id=projname type="hidden" name="for Ajax" value="'.$_SESSION['projname'].'">';
	echo '<input id=idrecord type="hidden" name="for Ajax" value="'.$_SESSION['id_record'].'">';
	//echo '<input id=qname type="hidden" name="for Ajax" value="custquest">';
	echo '<input id=qname type="hidden" name="for Ajax" value="'.$GLOBALS["qVar"]["q_name"].'">';
	echo '<input id=min type="hidden" name="for Ajax" value="'.$min.'">';
	echo '<input id=max type="hidden" name="for Ajax" value="'.$max.'">';
	// echo "GLOBELS Questionlabel: ".$GLOBALS["qVar"]["q_name"]."<br>";
	$savedValues = reset(getVar($GLOBALS["qVar"]["q_name"]."_1"));
	// dumpvar($savedValues);
	// echo "TEST ".$GLOBALS["qVar"]["q_name"];
	if ($savedValues != NULL && $savedValues != "") {	$values = reset(json_decode($savedValues,true));}
	//dumpvar($values);
	echo '<table  id="euroloop"  align="left"><tr><td>';
	echo '<div id="betrag"><fieldset>';
	//echo 'Wie viel ...?<br><br>';
	echo '<br><br>Betrag: <input type="text" id="betragop" autocomplete="off" ';
	if ($values["betragop"]!="") { echo "value=".$values["betragop"];}
	echo '><br><br>
	Weiß nicht<input type="radio" name="betragx" id="betragwn"';
	if ($values["betragwn"]==1) { echo "checked";}
	echo '>&nbsp&nbsp;&nbsp;keine Angaben<input type="radio" name="betragx" id="betragka"';
	if ($values["betragka"]==1) { echo "checked";}
	echo '>';
	if ($sonder != NULL) {
		echo '&nbsp&nbsp;&nbsp;'.$sonder.'<input type="radio" name="betragx" id="betragso"';
		if ($values["betragso"]==1) { echo "checked";}
		echo '>';
	}
	echo '</fieldset></div>';
	// echo '<br><mark>INTERVIEWER: Mögliche Eingaben zw. '.$min.' und '.$max.'.<br><br>Auch Angaben in einer anderen Währung aufnehmen.</mark><br><br>';
	echo '<div id= "bereich"><fieldset>
	Können Sie mir ein Intervall, d.h. Obergrenze und eine Untergrenze angeben, in dem der Betrag liegt?<br>';
	// echo '<mark>INTERVIEWER: SOWOHL DIE OBER- ALS AUCH DIE UNTERGRENZE KÖNNEN JEWEILS ALS “WEIß NICHT“ CODIERT WERDEN, UM EIN OFFENES INTERVALL ZU ERFASSEN, z.B. X=1.000 UND Y=“Weiß nicht“ BEDEUTET MEHR ALS 1000 EURO</mark><br><br><mark>';
	// echo 'INTERVIEWER: Auch Angaben in einer anderen Währung aufnehmen.</mark><br><br>';
	echo '<div id="unter">Untergrenze: <input type="text" id="unterop" autocomplete="off" ';
	if ($values["unterop"]!="") { echo "value=".$values["unterop"];}
	echo '>&nbsp;&nbsp;keine Untergrenze<input type="radio" id="unterka" ';
	if ($values["unterka"]==1) { echo "checked";}
	echo '><br><br></div>';
	echo '<div id="ober">Obergrenze: <input type="text" id="oberop" autocomplete="off" ';
	if ($values["oberop"]!="") { echo "value=".$values["oberop"];}
	echo '>&nbsp;&nbsp;keine Obergrenze<input type="radio" id="oberka"';
	if ($values["oberka"]==1) { echo "checked";}
	echo '><br><br></div>';

	echo '<br>';
	echo 'Weiß nicht<input type="radio" name="bereichx" id="bereichwn"';
	if ($values["bereichwn"]==1) { echo "checked";}
	echo '>&nbsp&nbsp;&nbsp;keine Angaben<input type="radio" name="bereichx" id="bereichka"';
	if ($values["bereichka"]==1) { echo "checked";}
	echo '>';
	echo '</fieldset></div>';
	echo '<div id="waehr"><fieldset><br>Währung:  <select name="waehrung">';
	//<option value="1" selected>Euro</option>
	if ($values["waehrung"]>=1) {
		$selectedWaehr = $values["waehrung"];
	} else if ($preWaehrung<>0)  {
		$selectedWaehr = $preWaehrung;
	} else {
		echo '<option disabled selected value> -- Währung auswählen -- </option>';
	}

	foreach($waehrungen as $key => $value) {
		$selected = '';
		if ($selectedWaehr==$key) $selected = 'selected';
		echo '<option value="'.$key.'" '.$selected.' >'.$value.'</option>';
		$selected ='';
	}
	echo '</select><br><br>';
	echo '<div id="waehrtxt">Währung notieren: <input type="text" id="waehrop" ';
	if ($values["waehrop"]!="") { echo "value=".$values["waehrop"];}
	echo '></div>';
	echo '</fieldset></div><br>';
	echo '<div id="kat"><fieldset>Können Sie mir das Intervall auf der Karte nennen, in dem der Betrag am wahrscheinlichsten liegt?<br><br>
	<mark>Interviewer: Karte - Eurointervalle "'.$interval.'"</mark><br><br>
	Kategorie: <select name="kategorie">
	<option disabled selected value> -- Kategorie auswählen -- </option>';
	//<option value="A">Kategorie A</option>
	foreach($kat as $key => $value) {
		$selected = '';
		if ($values["kategorie"]==$key) $selected = 'selected';
		echo '<option value="'.$key.'" '.$selected.' >'.$key.' - '.$value.'</option>';
		$selected ='';
	}
	$selectedwn = '';
	$selectedka = '';
	if ($values["kategorie"]=="1") $selectedwn = 'selected';
	if ($values["kategorie"]=="2") $selectedka = 'selected';
	// echo '<option value="'.$key.'" '.$selected.' >'.$key.' - '.$value.'</option>';
	echo '<option value="1" '.$selectedwn.' >weiß nicht</option>
	<option value="2" '.$selectedka.' >keine Angaben</option>
	</select><br>
	<input type="hidden" id="katgrp" name="katGrp" value="'.$interval.'"></fieldset></div>';
	echo '<input type="hidden" id="checked" ';
	if ($values["checked"]!="") { echo "value=".$values["checked"];}
	echo '>';
	echo '<input id="saveButton" type="button" value="Überprüfen" />';
	$betragtxt = '';
	if ($values["checked"]=="1") $bereichtxt = "<b>".$values["betragtxt"]."</b>";
	echo '</td></tr><tr><td id="betragtxt">'.$bereichtxt. '</td></tr>';
	//KONTROLLBUTTONS oder Fenster?
	echo '</table>';


	echo '<script>$(window).load(function () {
		var cell =  $("#betragtxt");
		var wrap = $("<div>").attr("id", "euroins").append("<br />").text("INTERVIEWER: Mögliche Eingaben zw. '.$min.' und '.$max.'.").css("background-color", "yellow").append("<br />").append(" Auch Angaben in einer anderen Währung aufnehmen.");
		cell.append(wrap);
	});
	</script>';
		//echo '<script language="JavaScript" type="text/javascript" src="../../webProjects/CustomSkripts/euroloop.js"></script>';
}
function saveId($id_resp=NULL) {
	$baseId = reset(getVar("EV_id_record"));
	$projName =  $_SESSION["proj_name"];
	$id_record = $_SESSION["id_record"];
	// echo $projName."-".$baseId."-".$id_record."<br>";
	$records = getVarFromTable("HFCS00_Base_structure", "links_1", "WHERE id=".$baseId);
	//echo $records[0]["links_1"];
	//dumpvar($records);
	$links = json_decode($records[0]["links_1"],true);
	if ($projName!="HFCS08_Erwerb") $links[$projName]["id_record"] = $id_record;
	else $links[$projName][$id_resp]["id_record"] = $id_record;
	$linksJson = json_encode($links,JSON_PRETTY_PRINT);
	if (saveVarToTable("HFCS00_Base_structure", "links_1",$linksJson, "WHERE id=".$baseId)) {
		// echo "ERFOLGREICH GESPEICHERT<br>";
		return true;
	}
}
function getVarFromHFCS($fbTeil,$label,$idResp=NULL) {
	$baseId = reset(getVar("EV_id_record"));
	//   echo '$baseId '.$baseId."<br>";
	//   echo '$fbTeil '.$fbTeil."<br>";
	$records = getVarFromTable("HFCS00_Base_structure", "links_1", "WHERE id=".$baseId);
	//   echo "links_1 ".$records[0]["links_1"]."<br>";
	$links = json_decode($records[0]["links_1"],true);
	// dumpvar($links);
	$linksFb = $links[$fbTeil];
	if ($idResp!=NULL)  $linksFb = $linksFb[$idResp];
	$targetId = $linksFb["id_record"];
	// dumpvar($linksFb);
	if ($fbTeil == "HFCS00_Base")  $targetId = $baseId;
	if ($targetId == NULL) return false;
	//   echo 'Dataser: '.$targetId." ";
	// dumpvar($links);
	$varValue = getVarFromTable($fbTeil."_structure", $label, "WHERE id=".$targetId);
	return($varValue[0]);
}
function getRespData($json,$part) {
	$respDataArray = json_decode($json,true);
	// dumpvar($respDataArray);
	return $respDataArray[$part];
}
function getJsonData($json,$part) {
	$respDataArray = json_decode($json,true);
	// dumpvar($respDataArray);
	return $respDataArray[0][$part];
}
function getValueFromKat($kategorie,$katgrp){
	$intervals = array(
		"A" => array(
			"A" => Array(1,100,50),
			"B" => Array(101,200,150),
			"C" => Array(201,300,250),
			"D" => Array(301,400,350),
			"E" => Array(401,500,450),
			"F" => Array(501,750,625),
			"G" => Array(751,1000,875),
			"H" => Array(1001,1500,1250),
			"I" => Array(1501,2000,1750),
			"J" => Array(2001,3000,2500),
			"K" => Array(3001,5000,4000),
			"L" => Array(5001,7500,6250),
			"M" => Array(7501,10000,8750),
			"N" => Array(10001,25000,1750),
			"O" => Array(25001,50000,3750),
			"P" => Array(50001,"",50001),
		),
		"B" => array(
			"A" => Array(1,10000,5000),
			"B" => Array(10001,50000,30000),
			"C" => Array(50001,75000,62500),
			"D" => Array(75001,100000,87500),
			"E" => Array(100001,150000,125000),
			"F" => Array(150001,200000,175000),
			"G" => Array(200001,300000,250000),
			"H" => Array(300001,400000,350000),
			"I" => Array(400001,500000,450000),
			"J" => Array(500001,750000,625000),
			"K" => Array(750001,1000000,875000),
			"L" => Array(1000001,3000000,2000000),
			"M" => Array(3000001,5000000,4000000),
			"N" => Array(5000001,10000000,7500000),
			"O" => Array(10000001,"",10000001),
		),
		"C" => array(
			"A" => Array(1,1000,500),
			"B" => Array(1001,2500,1250),
			"C" => Array(2501,5000,3750),
			"D" => Array(5001,7500,6250),
			"E" => Array(7501,10000,8750),
			"F" => Array(10001,15000,12500),
			"G" => Array(15001,20000,17500),
			"H" => Array(20001,25000,22500),
			"I" => Array(25001,30000,27500),
			"J" => Array(30001,35000,32500),
			"K" => Array(35001,40000,37500),
			"L" => Array(40001,50000,45000),
			"M" => Array(50001,75000,62500),
			"N" => Array(75001,100000,77500),
			"O" => Array(100001,200000,150000),
			"P" => Array(200001,300000,250000),
			"Q" => Array(300001,500000,400000),
			"R" => Array(500001,10000000,750000),
			"S" => Array(10000001,"",10000001),
		),
	);
	// echo"<pre>";
	// echo "Gruppe ".$katgrp."<br>";
	// var_dump($intervals["A"]);
	// echo"</pre>";
	return $intervals[$katgrp][$kategorie];
}
function getValueFromEuroloop($json) {
	$Wert_op = getJsonData($json,"betragop");
	// echo "OP: ".$Wert_op."<br>";
	$Wert_ug = getJsonData($json,"oberop");
	// echo "UG: ".$Wert_ug."<br>";
	$Wert_og = getJsonData($json,"unterop");
	// echo "OG: ".$Wert_og."<br>";
	$Wert_kat = getJsonData($json,"kategorie");
	$Wert_grp = getJsonData($json,"katgrp");
	// echo "Kat: ".$Wert_grp."-".$Wert_kat."<br>";
	$eurobase = "0";
	if ($Wert_op!="") $eurobase = $Wert_op;
	elseif ($Wert_ug!="" && $Wert_og!="") $eurobase = ($Wert_ug+$Wert_og)/2;
	elseif ($Wert_ug!="" && $Wert_og=="") $eurobase = $Wert_ug;
	elseif ($Wert_ug=="" && $Wert_og!="") $eurobase = $Wert_og;
	elseif ($Wert_ug=="" && $Wert_og=="" && $Wert_kat!="") {
		$euroArray = getValueFromKat($Wert_kat,$Wert_grp);
		$eurobase = $euroArray[2];
	}
	// echo $eurobase."<br>";
	return $eurobase;
}
function getEuro($label) {
	$json = reset(getVar($label."_1"));
	// echo "<br><br><br><br><br>";
	// echo "JSON (".$label."): ".$json."<br>";
	if($json=="")  return false;
	$eurobase = getValueFromEuroloop($json);
	// echo "eurobase (".$label."): ".$eurobase."<br>";
	$Wert_op = getJsonData($json,"betragop");
	$Wert_ug = getJsonData($json,"oberop");
	$Wert_og = getJsonData($json,"unterop");
	$Wert_kat = getJsonData($json,"kategorie");
	$waehrung = getJsonData($json,"waehrung");
	if ($Wert_op=="" && $Wert_ug=="" && $Wert_og=="" && $Wert_kat!="") $waehrung=1;
	if ($eurobase!=false && $eurobase=="") return false;
	if($waehrung==1) $eurobetrag = $eurobase;
	else if ($waehrung==2)  $eurobetrag = round($eurobase/13.7603, 0);
	else if ($waehrung==3)  $eurobetrag = round($eurobase/1.95583, 0);
	else return false;
	return $eurobetrag;
}
function checkBetrag($euro,$min=0,$max=999999999) {
	if ($euro==false) return false;
	if($euro>$min && $euro<$max) return true;
	else return false;
}
function getJsonValue($label,$key) {
	// echo "<br><br><br><br><br><br>";
	$dataJson = reset(getVar($label));
	// echo "JSON: ".$dataJson."<br>";
	$dataArray = reset(json_decode($dataJson,true));
	// dumpvar($dataArray);
	if(is_array($dataArray) && isset($dataArray[$key])) {
		// echo "WERT: ".$key."-".$dataArray[$key]."<br>";
		return $dataArray[$key];
	}
	return false;
}
function checkEligible($idResp) {
  $json = reset(getVarFromHFCS("HFCS01_Screener","dumPersFinalJs_".$idResp));
  if ($json!="") return true;
  return false;
}
function checkRedButton() {
	$label = array_keys($_POST["answers"]);
	// echo $label[0];
	$redButtonClicked = getJsonValue($label[0],"betragso");
	if ($redButtonClicked) return true;
	return false;
}
function beautyEuro($value) {
	if (strlen($value)>6 ) $euroBeauty .= substr($value,0,-6).".";
	if (strlen($value)>3 ) $euroBeauty .= substr(substr($value,-6),0,-3).".";
	if (strlen($value)>=1 ) $euroBeauty .= substr($value,-3,3);
	return $euroBeauty;
}
function checkRedButtonLoop($loopname) {
	$loop_count = array (
		"HB1010" => 3,
		"HB2410" => 3,
		"HB3010" => 5,
		"HC0340" => 3,
		"HC0410" => 3,
		"HD0210" => 3,
		"AHD1130" => 3,
		"HH0110" => 5,
	);
	$loops = array (
		"HB1010" => array (
			"HB120x1_12" => 12,
			"HB120srx1" => 12,
			"HB110x1" => 5,
			"AHB113x1_7" => 7,
			"AHB113srx1" => 7,
			"HB130x1" => 4,
			"AHB116x1" => 11,
			"HB140x1_1" => "json",
			"HB160x1" => 5,
			"HB170x1_1" => "json",
			"HB171x1" => 5,
			"HB180x1" => 5,
			"HB190x1" => 4,
			"AHB200x1_1" => "json",
			//"" => 0,
		),
		"HB2410" => array (
			"HB250x1" => 13,
			"AHB264x1" => 22,
			"AHB260x1_10" => 10,
			"AHB260srx1" => 10,
			"AHB265x1" => 8,
			"HB270x1" => 4,
			"AHB271x1" => 4,
			"AHB281x1_1" => "json",
			"HB280x1_1" => "json",

		),
		"HB3010" => array (
			"HB320x1_12" => 12,
			"HB320srx1" => 12,
			"AHB319x1" => 10,
			"HB310x1" => 5,
			"AHB313x1_7" => 7,
			"AHB313srx1" => 7,
			"HB330x1" => 4,
			"AHB316x1" => 11,
			"HB340x1_1" => "json",
			"HB360x1" => 4,
			"HB370x1_1" => "json",
			"HB371x1" => 4,
			"HB380x1" => 5,
			"HB390x1" => 4,
			"AHB400x1_1" => "json",
		),
		"HC0340" => array (
			"AHC035x1_14" => 14,
			"AHC035srx1" => 14,
			"HC036x1_1" => "json",
		),
		"HC0410" => array (
			"AHC050x1_14" => 14,
			"AHC050srx1" => 14,
			"AHC059x1" => 4,
			"AHC055x1" => 11,
			"HC060x1_1" => "json",
			"HC070x1" => 5,
			"HC080x1_1" => "json",
			"HC090x1" => 4,
			"AHC100x1_1" => "json",
		),
		"HD0210" => array (
			"HD030x1" => 24,
			"AHD040x1" => 10,
			"HD050x1" => 4,
			"AHD051x1" => 3,
			"AHD060x1_18" => 18,
			"HD070x1" => 4,
			// "HD080x1_1" => "json",
			"AHD081x1_1" => "json",
			"AHD082x1" => 5,
		),
		"AHD1130" => array (
			"AHD114x1" => 4,
			"AHD115x1" => 4,
			"AHD116x1" => 6,
			"AHD117x1" => 6,
			"AHD118x1_1" => "json",
		),
		"HH0110" => array (
			"HH020x1" => 4,
			"AHH030x1_14" => 14,
			"AHH030srx1" => 13,
			"HH040x1_1" => "json",
			"HH050x1" => 5,
			"AHH060x1" => 1,
		),
	);
	// echo "<br><br><br><br><br>TEST REDBUTTON<br>";
	$questId = $_SESSION['nextQuestion'][0]["id"];
	$curLabel = idToName($questId);
	// echo "<br>-".$questId.$curLabel."-<br>";
	$loop = substr($curLabel,strpos($curLabel,"x")-strlen($curLabel)+1);
	$curlabelTox1 = str_replace ("x".$loop,"x1",$curLabel);
	// echo "<br>-".$curlabelTox1."-<br>";

	$inLoop=false;
	foreach($loops[$loopname] as $label => $value) {
		if (strpos($label,$curlabelTox1)===0 ) {
			// echo "<br>-in Loop-<br>";
			$inLoop=true;
		}
	}
	for($icount=1;$icount<=$loop_count[$loopname];$icount++) {
		foreach($loops[$loopname] as $label => $value) {
			$label = str_replace ("x1","x".$icount,$label);
			// echo "<br>-".$icount."-".$label."-".$curLabel."-<br>";
			if (strpos($label,$curLabel)===0 || !$inLoop) {
				// echo "<br><br><br><br>korrekte Frage<br>$label";
				if ($value == "json") {
					if (reset(getVar($label))!= NULL && getJsonValue($label,"betragso")==1) return true;
				} else {
					if (reset(getVar($label))==$value) return true;
				}
			}
		}
	}
	// echo "<br><br><br><br><br>TEST REDBUTTON<br>";
	return false;
}
function getAnswerText($label,$item=NULL) {
	if(strpos($label,"_")) $qname=substr($label,0,strpos($label,"_"));
	else $qname=$label;
	// echo "<br><br><br><br><br><br>";
	// return true;
	$projName =  $_SESSION["proj_name"];
	$id = getVarFromTable("Warpit_Webcati.".$projName, "id", "WHERE q_name='".$qname."'");
	$id = reset($id[0]);
	$answersText =  getVarFromTable("Warpit_Webcati.".$projName."_language", "lngText", "WHERE id_question=".$id." AND id_text_type=3");
	$answersText = reset($answersText[0]);
	$answersTextArray = explode("/",$answersText);
	if ($item==NULL) $value = reset(getVar($label));
	else $value = $item;
	$answerText = $answersTextArray[$value-1];
	$answerText = strstr($answerText," ");
	$answerText = substr($answerText,1);
	// echo $answerText;
	return $answerText;
}

function linkBack($HFCS_ARRAY) {
	$questtxt ="";
	$newUrl = 0;
	$urlPath = $GLOBALS["paths"]["warpit_www"];
	$urlPath = str_replace("8080:8080","8080",$urlPath);
	$urlPath = str_replace("81:81","81",$urlPath);
	$links = json_decode(reset(getVarFromHFCS("HFCS00_Base","links_1")),true);
	$id_loginSID = reset(getVarFromHFCS("HFCS00_Base","id_loginSID"));
	$loginSID = reset(getVarFromTable("_www_ids","loginSID","WHERE id = ".$id_loginSID));
	$id_record = reset(getVar("EV_id_record"));
	$aktFrabo = $_SESSION["proj_name"];
	$url2 = $urlPath."survey/index.php?loginSID=".$loginSID["loginSID"]."&id_record=".$id_record;
	$newUrl = $url2;
	// echo "<br><br><br><br>";
	// var_dump($_SESSION);
	foreach ($HFCS_ARRAY as $fbTeil=>$value) {
		// echo $fbTeil;
		if ($fbTeil == $aktFrabo) break;
		$linkConfig = $links[$fbTeil];
		// dumpvar($linkConfig);
		if ($fbTeil == "HFCS08_Erwerb") {
			foreach($linkConfig as $key => $linkConfigPers) {
				$url = $urlPath."survey/index.php?loginSID=".$linkConfigPers["loginSID"]."&id_record=".$id_record;
				$url .= "&id_resp=".$key;
				if ($linkConfigPers["status"]==1) {
					if ($key==1) $newUrl=$url;
				}
			}
		} else {
			$url = $urlPath."survey/index.php?loginSID=".$linkConfig["loginSID"]."&id_record=".$id_record;
			if ($linkConfig["status"]==1) {
				$newUrl=$url;
			}
		}
	}
	$questtxt .= '<table style="float:left;border-collapse: collapse;"><tr><td><a href="'.$newUrl.'"  target="_top"><- Zurück'."</a></td></tr></table><br><br><br>";
	return $questtxt;
}
function checkComplete() {
	$links = json_decode(reset(getVarFromHFCS("HFCS00_Base","links_1")),true);
	$id_record = reset(getVar("EV_id_record"));
	$linkConfig = $links["HFCS11_Einschaetzung"];
	// echo "<br><br><br><br><br>";
	// var_dump($linkConfig);
	if ($linkConfig["status"]!=1) return false;
	return true;
}
function checkAbbruch() {
	$abr_AHL0120 = reset(getVarFromHFCS("HFCS01_Screener","AHL0120"));
	$abr_AHL0140 = reset(getVarFromHFCS("HFCS01_Screener","AHL0140"));
	if ($abr_AHL0120==6 || $abr_AHL0140==2) return true;
	return false;
}
?>
